local type   = type
local string = string

local en = Turbine.Language.English
local fr = Turbine.Language.French
local de = Turbine.Language.German
local ru = Turbine.Language.Russian

Group.language = Turbine.Engine.GetLanguage()

if Group.language == Turbine.Language.EnglishGB then Group.language = Turbine.Language.English end

function Group:Local( str )
    if not ( type( str ) == "string" ) then return "N/A" end

    if not self.Localization[ str ] then return "N/A" end

    if not ( self.Localization[ str ][ self.language ] == "" ) then
        return self.Localization[ str ][ self.language ]
    else
        if not ( self.Localization[ str ][ en ] == "" ) then
            return self.Localization[ str ][ en ]
        else
            return "N/A"
        end
    end
end

function Group:SetLanguage( language )
    self.language = language
end

function Group:GetLanguage()
    return self.language
end

Group.Localization = {
    --[[

    TEST = {
        [ en ] = "TEST",
        [ fr ] = "",
        [ de ] = "TEST",
        [ ru ] = ""
    },

    ]]

    --Plugin Version

    Internal_Version = { --Include a space at the end!
        [ en ] = "Version ",
        [ fr ] = "",
        [ de ] = "Version ",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Effect names used internally
    --These needs to be checked ingame on the correct client to make sure it's accurate.

    Internal_CC_1 = { --Needs to be the exact effect name!
        [ en ] = "Stunned",
        [ fr ] = "",
        [ de ] = "Betäubt",
        [ ru ] = ""
    },

    Internal_CC_2 = { --Needs to be the exact effect name!
        [ en ] = "Knocked Down",
        [ fr ] = "",
        [ de ] = "Niedergeschlagen",
        [ ru ] = ""
    },

    Internal_CC_3 = { --Needs to be the exact effect name!
        [ en ] = "Dazed",
        [ fr ] = "",
        [ de ] = "Benommenheit",
        [ ru ] = ""
    },

    Internal_CC_4 = { --Needs to be the exact effect name!
        [ en ] = "Rooted",
        [ fr ] = "",
        [ de ] = "Angewurzelt",
        [ ru ] = ""
    },

    Internal_CC_5 = { --Needs to be the exact effect name!
        [ en ] = "Feared",
        [ fr ] = "",
        [ de ] = "Gefürchtet",
        [ ru ] = ""
    },

    Internal_CC_6 = { --Needs to be the exact effect name!
        [ en ] = "Slow",
        [ fr ] = "",
        [ de ] = "Verlangsamt",
        [ ru ] = ""
    },

    Internal_CC_7 = { --Needs to be the exact effect name!
        [ en ] = "Frost-fingered Fear",
        [ fr ] = "",
        [ de ] = "Saat der Meinungsverschiedenheit",
        [ ru ] = ""
    },

    Internal_DNF = {  --Needs to be the exact effect name!
        [ en ] = "Do Not Fall This Day",
        [ fr ] = "",
        [ de ] = "Tod heute nicht unterliegen",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Chat messages related to Fellowships and Raids, these need to be accurate or the plugin wont work properly!

    --You can't translate this directly, you need to check ingame what message is displayed in the chat when you leave, join, kick etc...

    --To make sure this is accurate you need to test it on the client in question ( English, French, German, Russian? )

    --Please note as different languages are structured differently syntax vise, this may not fit in certain lines as the <Name> may not be in the same place.
    --If this is the case please contact me and i will work out a solution.

    Chat_Raid_Convert = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You have joined the chat room for your raid, raid chat is now available." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr habt den Chat-Raum Eurer Gefährtengruppe betreten. Der Gefährten-Chat ist jetzt verfügbar." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Join = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has joined your Fellowship." ), -- "<Name> has joined your Fellowship."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " hat sich Eurer Gruppe von Gefährten angeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Join = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has joined your Raid." ), -- "<Name> has joined your Raid."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " hat sich Eurem Schlachtzug angeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Join_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You have joined a Fellowship." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr habt Euch einer Gruppe von Gefährten angeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Join_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You have joined a Raid." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr habt Euch einem Schlachtzug angeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Leave = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has left your Fellowship." ), -- "<Name> has left your Fellowship."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " hat Eure Gruppe von Gefährten verlassen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Leave = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has left your Raid." ), -- "<Name> has left your Raid."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " hat Euren Schlachtzug verlassen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Leave_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You leave your Fellowship." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr verlasst Eure Gruppe von Gefährten." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Leave_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You leave your Raid." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr verlasst den Schlachtzug." ),
        [ ru ] = string.lower( "" )
    },

    ------------------------------------------------------

    --Full message: "You dismiss <Name> from the fellowship." and "You dismiss <Name> from the Raid."

    Chat_Self_Dismiss_Start = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( "You dismiss " ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr schließt " ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Dismiss_End = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " from the fellowship." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " aus der Gruppe von Gefährten aus." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Dismiss_End = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " from the Raid." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " aus dem Schlachtzug aus." ),
        [ ru ] = string.lower( "" )
    },

    ------------------------------------------------------

    Chat_Fellowship_Dismiss = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has been dismissed from your Fellowship." ), -- "<Name> has been dismissed from your Fellowship."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " wurde aus Eurer Gruppe von Gefährten ausgeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Dismiss = { --Needs to be the exact message, capital letters doesn't matter. Include the spaces, but not the name.
        [ en ] = string.lower( " has been dismissed from your Raid." ), -- "<Name> has been dismissed from your Raid."
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( " wurde aus Eurem Schlachtzug ausgeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Dismiss_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You have been dismissed from your Fellowship." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr wurdet aus Eurer Gruppe von Gefährten ausgeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Dismiss_Self = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "You have been dismissed from your Raid." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Ihr wurdet aus Eurem Schlachtzug ausgeschlossen." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Fellowship_Disband = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "Your Fellowship has been disbanded." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Eure Gruppe von Gefährten wurde aufgelöst." ),
        [ ru ] = string.lower( "" )
    },

    Chat_Raid_Disband = { --Needs to be the exact message, capital letters doesn't matter.
        [ en ] = string.lower( "Your Raid has been disbanded." ),
        [ fr ] = string.lower( "" ),
        [ de ] = string.lower( "Euer Schlachtzug wurde aufgelöst." ),
        [ ru ] = string.lower( "" )
    },

    ------------------------------------------------------

    --Chat commands

    -- /miniraid options
    -- /miniraid reload
    -- /miniraid record start
    -- /miniraid record stop

    --Must not include any spaces!

    Chat_Command_Self = {
        [ en ] = "miniraid",
        [ fr ] = "",
        [ de ] = "miniraid",
        [ ru ] = ""
    },

    Chat_Command_Options = {
        [ en ] = "options",
        [ fr ] = "",
        [ de ] = "optionen",
        [ ru ] = ""
    },

    Chat_Command_Effects = {
        [ en ] = "effects",
        [ fr ] = "",
        [ de ] = "effekte",
        [ ru ] = ""
    },

    Chat_Command_Reload = {
        [ en ] = "reload",
        [ fr ] = "",
        [ de ] = "neu laden",
        [ ru ] = ""
    },

    Chat_Command_Record = {
        [ en ] = "record",
        [ fr ] = "",
        [ de ] = "aufzeichnen",
        [ ru ] = ""
    },

    Chat_Command_Help = {
        [ en ] = "help",
        [ fr ] = "",
        [ de ] = "hilfe",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Chat Messages

    Chat_Message_Invalid = { --Include a colon and space at the end!
        [ en ] = "Invalid command: ",
        [ fr ] = "",
        [ de ] = "Unbekannter Befehl: ",
        [ ru ] = ""
    },

    Chat_Message_Help = {
        [ en ] = "Commands:\n" ..
                 "        /miniraid options\n" .. 
                 "        /miniraid effects\n" ..
                 "        /miniraid record\n" ..
                 "        /miniraid reload\n" .. 
                 "        /miniraid help\n",
        [ fr ] = "",
        [ de ] = "Befehle:\n" ..
                 "        /miniraid optionen\n" .. 
                 "        /miniraid effekte\n" ..
                 "        /miniraid aufnehmen\n" ..
                 "        /miniraid neu laden\n" .. 
                 "        /miniraid hilfe\n",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Notifications

    Notification_Record_Start = {
        [ en ] = "Effects are now being recorded!",
        [ fr ] = "",
        [ de ] = "Effekte werden jetzt aufgezeichnet!",
        [ ru ] = ""
    },

    Notification_Record_Stop = {
        [ en ] = "Effects are no longer being recorded!",
        [ fr ] = "",
        [ de ] = "Effekte werden nicht mehr aufgezeichnet!",
        [ ru ] = ""
    },

    Notification_Toggle_Off = {
        [ en ] = "Party layout has been made invisible!",
        [ fr ] = "",
        [ de ] = "Gruppenlayout wurde ausgeblendet!",
        [ ru ] = ""
    },

    Notification_Toggle_On = {
        [ en ] = "Party layout is now visible!",
        [ fr ] = "",
        [ de ] = "Gruppenlayout ist jetzt sichtbar!",
        [ ru ] = ""
    },

    Notification_Effect_Track = {
        [ en ] = "\"<effect>\" is now being tracked!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" wird jetzt verfolgt!",
        [ ru ] = ""
    },

    Notification_Effect_Alert = {
        [ en ] = "\"<effect>\" is now being alerted!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" löst jetzt eine Warnung aus!",
        [ ru ] = ""
    },

    Notification_Effect_Blacklist = {
        [ en ] = "\"<effect>\" has been added to the blacklist!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" wurde zur Schwarzen Liste hinzugefügt!",
        [ ru ] = ""
    },

    Notification_Effect_Special = {
        [ en ] = "\"<effect>\" has been set as special effect!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" als Spezialeffekt festgelegt!",
        [ ru ] = ""
    },

    Notification_Effect_Track_Removed = {
        [ en ] = "\"<effect>\" has been removed from tracking!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" wird jetzt von der Verfolgung ausgenommen!",
        [ ru ] = ""
    },

    Notification_Effect_Alert_Removed = {
        [ en ] = "\"<effect>\" has been removed from alerts!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" aus der Liste der Warnungen entfernt!",
        [ ru ] = ""
    },

    Notification_Effect_Blacklist_Removed = {
        [ en ] = "\"<effect>\" has been removed from the blacklist!",
        [ fr ] = "",
        [ de ] = "\"<effect>\" wurde von der Schwarzen Liste entfernt!",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Text for the player frame.

    Frame_Text_Dead = {
        [ en ] = "Defeated",
        [ fr ] = "",
        [ de ] = "besiegt",
        [ ru ] = ""
    },

    Frame_Text_Offline = {
        [ en ] = "Offline",
        [ fr ] = "",
        [ de ] = "offline",
        [ ru ] = ""
    },

    Frame_Text_Ready = {
        [ en ] = "Ready",
        [ fr ] = "",
        [ de ] = "fertig",
        [ ru ] = ""
    },

    Frame_Text_Waiting = {
        [ en ] = "Waiting",
        [ fr ] = "",
        [ de ] = "wartet",
        [ ru ] = ""
    },

    Frame_Text_Not_Ready = {
        [ en ] = "Not Ready",
        [ fr ] = "",
        [ de ] = "nicht fertig",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --UI

    UI_Textbox_Effect = {
        [ en ] = "Effect Name",
        [ fr ] = "",
        [ de ] = "Effektname",
        [ ru ] = ""
    },

    UI_Button_Reset = {
        [ en ] = "Reset",
        [ fr ] = "",
        [ de ] = "Zurücksetzen",
        [ ru ] = ""
    },

    UI_Button_Center = {
        [ en ] = "Center",
        [ fr ] = "",
        [ de ] = "Mitte",
        [ ru ] = ""
    },

    UI_Dropdown_Left = {
        [ en ] = "Left",
        [ fr ] = "",
        [ de ] = "Links",
        [ ru ] = ""
    },

    UI_Dropdown_Center = {
        [ en ] = "Center",
        [ fr ] = "",
        [ de ] = "Mitte",
        [ ru ] = ""
    },

    UI_Dropdown_Right = {
        [ en ] = "Right",
        [ fr ] = "",
        [ de ] = "Rechts",
        [ ru ] = ""
    },

    UI_Dropdown_Top = {
        [ en ] = "Top",
        [ fr ] = "",
        [ de ] = "Oben",
        [ ru ] = ""
    },

    UI_Dropdown_Bottom = {
        [ en ] = "Bottom",
        [ fr ] = "",
        [ de ] = "Unten",
        [ ru ] = ""
    },

    UI_Dropdown_Top_Left = {
        [ en ] = "Top Left",
        [ fr ] = "",
        [ de ] = "Oben Links",
        [ ru ] = ""
    },

    UI_Dropdown_Top_Right= {
        [ en ] = "Top Right",
        [ fr ] = "",
        [ de ] = "Oben Rechts",
        [ ru ] = ""
    },

    UI_Dropdown_Bottom_Left = {
        [ en ] = "Bottom Left",
        [ fr ] = "",
        [ de ] = "Unten Links",
        [ ru ] = ""
    },

    UI_Dropdown_Bottom_Right = {
        [ en ] = "Bottom Right",
        [ fr ] = "",
        [ de ] = "Unten Rechts",
        [ ru ] = ""
    },

    UI_Dropdown_Format_1 = {
        [ en ] = "%",
        [ fr ] = "",
        [ de ] = "%",
        [ ru ] = ""
    },

    UI_Dropdown_Format_2 = {
        [ en ] = "Current",
        [ fr ] = "",
        [ de ] = "Aktuell",
        [ ru ] = ""
    },

    UI_Dropdown_Format_3 = {
        [ en ] = "Current + %",
        [ fr ] = "",
        [ de ] = "Aktuell + %",
        [ ru ] = ""
    },

    UI_Dropdown_Format_4 = {
        [ en ] = "Current / Max",
        [ fr ] = "",
        [ de ] = "Aktuell / Max",
        [ ru ] = ""
    },

    UI_Dropdown_Format_5 = {
        [ en ] = "Current / Max + %",
        [ fr ] = "",
        [ de ] = "Aktuell / Max + %",
        [ ru ] = ""
    },

    UI_Dropdown_Format_6 = {
        [ en ] = "Current ( K )",
        [ fr ] = "",
        [ de ] = "Aktuell ( K )",
        [ ru ] = ""
    },

    UI_Dropdown_Format_7 = {
        [ en ] = "Current + % ( K )",
        [ fr ] = "",
        [ de ] = "Aktuell + % ( K )",
        [ ru ] = ""
    },

    UI_Dropdown_Format_8 = {
        [ en ] = "Current / Max ( K )",
        [ fr ] = "",
        [ de ] = "Aktuell / Max ( K )",
        [ ru ] = ""
    },

    UI_Dropdown_Format_9 = {
        [ en ] = "Current / Max + % ( K )",
        [ fr ] = "",
        [ de ] = "Aktuell / Max + % ( K )",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Quick Menu

    QuickMenu_Record = {
        [ en ] = "Recording:",
        [ fr ] = "",
        [ de ] = "Aufzeichnen:",
        [ ru ] = ""
    },

    QuickMenu_Status_On = {
        [ en ] = "On",
        [ fr ] = "",
        [ de ] = "An",
        [ ru ] = ""
    },

    QuickMenu_Status_Off = {
        [ en ] = "Off",
        [ fr ] = "",
        [ de ] = "Aus",
        [ ru ] = ""
    },

    QuickMenu_Options = {
        [ en ] = "Options",
        [ fr ] = "",
        [ de ] = "Optionen",
        [ ru ] = ""
    },

    QuickMenu_Effects = {
        [ en ] = "Effects",
        [ fr ] = "",
        [ de ] = "Effekte",
        [ ru ] = ""
    },

    QuickMenu_Toggle = {
        [ en ] = "Toggle",
        [ fr ] = "",
        [ de ] = "Umschalten",
        [ ru ] = ""
    },

    QuickMenu_Reload = {
        [ en ] = "Reload",
        [ fr ] = "",
        [ de ] = "Neu laden",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Options menu

    Options = {
        [ en ] = "MiniRaid Options",
        [ fr ] = "",
        [ de ] = "MiniRaid Optionen",
        [ ru ] = ""
    },

    Options_Vanilla_Toggle = {
        [ en ] = "Disable Vanilla Party Vitals",
        [ fr ] = "",
        [ de ] = "Originale Lebensanzeige der Gefährten ausblenden",
        [ ru ] = ""
    },

    Options_Vanilla_Player_Toggle = {
        [ en ] = "Disable Vanilla Player Vitals",
        [ fr ] = "",
        [ de ] = "Originale Lebensanzeige des Spielers ausblenden",
        [ ru ] = ""
    },

    Options_QuickMenu = {
        [ en ] = "Enable UI quickmenu button",
        [ fr ] = "",
        [ de ] = "Button für UI Schnellmenü aktivieren",
        [ ru ] = ""
    },

    Options_QuickMenu_Note = {
        [ en ] = "Enables a quickmenu button with a dropdown menu for easy access to the entire plugin. Hold shift and drag with your mouse to the position where you want it.",
        [ fr ] = "",
        [ de ] = "Aktiviert einen Button mit einem ausklappbaren Menü, das schnellen Zugriff auf das gesamte Plugin bietet. Zum Positionieren die Umschalttaste/Shift gedrückt halten und mit der Maus an die gewünschte Position ziehen. ",
        [ ru ] = ""
    },

    Options_Preview = {
        [ en ] = "Preview",
        [ fr ] = "",
        [ de ] = "Vorschau",
        [ ru ] = ""
    },

    --Tabs

    Options_Tab_1 = {
        [ en ] = "Help",
        [ fr ] = "",
        [ de ] = "Hilfe",
        [ ru ] = ""
    },

    Options_Tab_2 = {
        [ en ] = "Misc",
        [ fr ] = "",
        [ de ] = "Versch",
        [ ru ] = ""
    },

    Options_Tab_3 = {
        [ en ] = "Font",
        [ fr ] = "",
        [ de ] = "Schriftart",
        [ ru ] = ""
    },

    Options_Tab_4 = {
        [ en ] = "Class",
        [ fr ] = "",
        [ de ] = "Klasse",
        [ ru ] = ""
    },

    Options_Tab_5 = {
        [ en ] = "Color",
        [ fr ] = "",
        [ de ] = "Farbe",
        [ ru ] = ""
    },

    Options_Tab_6 = {
        [ en ] = "Frame",
        [ fr ] = "",
        [ de ] = "Rahmen",
        [ ru ] = ""
    },

    Options_Tab_7 = {
        [ en ] = "Layout",
        [ fr ] = "",
        [ de ] = "Layout",
        [ ru ] = ""
    },

    --Layout

    Options_Layout_Party_3 = {
        [ en ] = "1 - 3 Players",
        [ fr ] = "",
        [ de ] = "1 - 3 Spieler",
        [ ru ] = ""
    },

    Options_Layout_Party_6 = {
        [ en ] = "4 - 6 Players",
        [ fr ] = "",
        [ de ] = "4 - 6 Spieler",
        [ ru ] = ""
    },

    Options_Layout_Party_12 = {
        [ en ] = "7 - 12 Players",
        [ fr ] = "",
        [ de ] = "7 - 12 Spieler",
        [ ru ] = ""
    },

    Options_Layout_Party_18 = {
        [ en ] = "13 - 18 Players",
        [ fr ] = "",
        [ de ] = "13 - 18 Spieler",
        [ ru ] = ""
    },

    Options_Layout_Party_24 = {
        [ en ] = "19 - 24 Players",
        [ fr ] = "",
        [ de ] = "19 - 24 Spieler",
        [ ru ] = ""
    },

    Options_Layout_Party_Description = {
        [ en ] = "Usage: Allows you to set the grid layout for different party sizes.",
        [ fr ] = "",
        [ de ] = "Benutzung: Ermöglicht das Konfigurieren eines Raster-Layouts für verschiedene Gruppengrößen.",
        [ ru ] = ""
    },

    Options_Layout_Horizontal = {
        [ en ] = "Horizontal Layout Direction",
        [ fr ] = "",
        [ de ] = "Horizontale Layoutausrichtung",
        [ ru ] = ""
    },

    Options_Layout_Vertical = {
        [ en ] = "Vertical Layout Direction",
        [ fr ] = "",
        [ de ] = "Vertikale Layoutausrichtung",
        [ ru ] = ""
    },

    Options_Layout_Spacing = {
        [ en ] = "Spacing",
        [ fr ] = "",
        [ de ] = "Abstand",
        [ ru ] = ""
    },

    Options_Layout_Position = {
        [ en ] = "Position",
        [ fr ] = "",
        [ de ] = "Position",
        [ ru ] = ""
    },

    Options_Layout_Preview = {
        [ en ] = "Enable Layout Preview",
        [ fr ] = "",
        [ de ] = "Layoutvorschau aktivieren",
        [ ru ] = ""
    },

    Options_Layout_Preview_Count = {
        [ en ] = "Player Count ( Preview )",
        [ fr ] = "",
        [ de ] = "Spieleranzahl ( Vorschau )",
        [ ru ] = ""
    },

    Options_Layout_Unique_Player_Pos = {
        [ en ] = "Detach player frame from the party layout",
        [ fr ] = "",
        [ de ] = "Spielerrahmen vom Gruppenlayout abdocken",
        [ ru ] = ""
    },

    Options_Layout_Unique_Player_Position = {
        [ en ] = "Player Frame Position",
        [ fr ] = "",
        [ de ] = "Position des Spielerrahmens",
        [ ru ] = ""
    },

    Options_Layout_Combat_Hide = {
        [ en ] = "Hide Layout When Out Of Combat",
        [ fr ] = "",
        [ de ] = "Layout außerhalb des Kampfes ausblenden",
        [ ru ] = ""
    },

    Options_Layout_Show_Solo = {
        [ en ] = "Show Player Frame While Not In A Party",
        [ fr ] = "",
        [ de ] = "Spielerrahmen anzeigen, wenn dieser nicht in einer Gruppe ist",
        [ ru ] = ""
    },

    --Frame

    Options_Frame_Size = {
        [ en ] = "Frame Size",
        [ fr ] = "",
        [ de ] = "Rahmengröße",
        [ ru ] = ""
    },

    Options_Frame_Power_Size = {
        [ en ] = "Power Bar Size",
        [ fr ] = "",
        [ de ] = "Größe des Kraftbalkens",
        [ ru ] = ""
    },

    Options_Frame_Selection_Size = {
        [ en ] = "Selection Size",
        [ fr ] = "",
        [ de ] = "Größe der Auswahl",
        [ ru ] = ""
    },

    Options_Frame_Name_Position = {
        [ en ] = "Name Position",
        [ fr ] = "",
        [ de ] = "Position des Namens",
        [ ru ] = ""
    },

    Options_Frame_Name_Anchor = {
        [ en ] = "Name Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für Namen",
        [ ru ] = ""
    },

    Options_Frame_Name_Size = {
        [ en ] = "Name Width",
        [ fr ] = "",
        [ de ] = "Breite des Namensfeldes",
        [ ru ] = ""
    },

    Options_Frame_Name_Preview = {
        [ en ] = "Show Bounds ( Preview )",
        [ fr ] = "",
        [ de ] = "Begrenzung anzeigen ( Vorschau )",
        [ ru ] = ""
    },

    Options_Frame_Class_Position = {
        [ en ] = "Class Icon Position",
        [ fr ] = "",
        [ de ] = "Position für das Klassensymbol",
        [ ru ] = ""
    },

    Options_Frame_Class_Anchor = {
        [ en ] = "Class Icon Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für das Klassensymbol",
        [ ru ] = ""
    },

    Options_Frame_Class_Size = {
        [ en ] = "Class Icon Size",
        [ fr ] = "",
        [ de ] = "Größe des Klassensymbols",
        [ ru ] = ""
    },

    Options_Frame_Leader_Position = {
        [ en ] = "Leader Icon Position",
        [ fr ] = "",
        [ de ] = "Position des Anführersymbols",
        [ ru ] = ""
    },

    Options_Frame_Leader_Anchor = {
        [ en ] = "Leader Icon Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für das Anführersymbol",
        [ ru ] = ""
    },

    Options_Frame_Leader_Size = {
        [ en ] = "Leader Icon Size",
        [ fr ] = "",
        [ de ] = "Größe des Anführersymbols",
        [ ru ] = ""
    },

    Options_Frame_Morale_Position = {
        [ en ] = "Morale Text Position",
        [ fr ] = "",
        [ de ] = "Position des Moralwerts",
        [ ru ] = ""
    },

    Options_Frame_Morale_Anchor = {
        [ en ] = "Morale Text Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für den Moralwert",
        [ ru ] = ""
    },

    Options_Frame_Morale_Format = {
        [ en ] = "Morale Text Format",
        [ fr ] = "",
        [ de ] = "Textformat für den Moralwert",
        [ ru ] = ""
    },

    Options_Frame_Power_Position = {
        [ en ] = "Power Text Position",
        [ fr ] = "",
        [ de ] = "Position des Kraftwerts",
        [ ru ] = ""
    },

    Options_Frame_Power_Anchor = {
        [ en ] = "Power Text Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für den Kraftwert",
        [ ru ] = ""
    },

    Options_Frame_Power_Format = {
        [ en ] = "Power Text Format",
        [ fr ] = "",
        [ de ] = "Textformat für den Kraftwert",
        [ ru ] = ""
    },

    Options_Frame_Effect_Position = {
        [ en ] = "Effects Position",
        [ fr ] = "",
        [ de ] = "Position für die Effektanzeige",
        [ ru ] = ""
    },

    Options_Frame_Effect_Anchor = {
        [ en ] = "Effects Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für die Effektanzeige",
        [ ru ] = ""
    },

    Options_Frame_Effect_Size = {
        [ en ] = "Effect Size",
        [ fr ] = "",
        [ de ] = "Anzeigegröße von Effekten",
        [ ru ] = ""
    },

    Options_Frame_Effect_Spacing = {
        [ en ] = "Effect Spacing",
        [ fr ] = "",
        [ de ] = "Effektanzeige: Abstände",
        [ ru ] = ""
    },

    Options_Frame_Effect_Flash_Threshold = {
        [ en ] = "Effect Flash Threshold",
        [ fr ] = "",
        [ de ] = "Effektanzeige: Schwelle für Blinken",
        [ ru ] = ""
    },

    Options_Frame_Effect_Duration_Threshold = {
        [ en ] = "Effect Duration Threshold",
        [ fr ] = "",
        [ de ] = "Effektanzeige: Schwelle für Effektdauer",
        [ ru ] = ""
    },

    Options_Frame_Effect_Count_Preview = {
        [ en ] = "Effect Count ( Preview )",
        [ fr ] = "",
        [ de ] = "Effektanzeige: Anzahl ( Vorschau )",
        [ ru ] = ""
    },

    Options_Frame_Effect_Max_Row = {
        [ en ] = "Max Effects Per Row",
        [ fr ] = "",
        [ de ] = "Maximale Effekte pro Reihe",
        [ ru ] = ""
    },

    Options_Frame_Special_Position = {
        [ en ] = "Special Effect Position",
        [ fr ] = "",
        [ de ] = "Position für die Anzeige von Spezialeffekten",
        [ ru ] = ""
    },

    Options_Frame_Special_Anchor = {
        [ en ] = "Special Effect Anchor Point",
        [ fr ] = "",
        [ de ] = "Verankerungspunkt für Spezialeffekte",
        [ ru ] = ""
    },

    Options_Frame_Special_Size = {
        [ en ] = "Special Effect Size",
        [ fr ] = "",
        [ de ] = "Größe von Spezialeffekten",
        [ ru ] = ""
    },

    --Color

    Options_Color_Morale = {
        [ en ] = "Morale",
        [ fr ] = "",
        [ de ] = "Moral",
        [ ru ] = ""
    },

    Options_Color_Power = {
        [ en ] = "Power",
        [ fr ] = "",
        [ de ] = "Kraft",
        [ ru ] = ""
    },

    Options_Color_Bubble = {
        [ en ] = "Bubble",
        [ fr ] = "",
        [ de ] = "Bubble",
        [ ru ] = ""
    },

    Options_Color_Dead = {
        [ en ] = "Defeated",
        [ fr ] = "",
        [ de ] = "Besiegt",
        [ ru ] = ""
    },

    Options_Color_Background = {
        [ en ] = "Background",
        [ fr ] = "",
        [ de ] = "Hintergrund",
        [ ru ] = ""
    },

    Options_Color_Threshold = {
        [ en ] = "Threshold",
        [ fr ] = "",
        [ de ] = "Schwelle",
        [ ru ] = ""
    },

    Options_Color_Selected = {
        [ en ] = "Selected",
        [ fr ] = "",
        [ de ] = "Auswahl",
        [ ru ] = ""
    },

    Options_Color_Hover = {
        [ en ] = "Hover",
        [ fr ] = "",
        [ de ] = "Mouseover",
        [ ru ] = ""
    },

    Options_Color_Unique_Morale = {
        [ en ] = "Unique Morale",
        [ fr ] = "",
        [ de ] = "Eigene Moral",
        [ ru ] = ""
    },

    Options_Color_Wrath = {
        [ en ] = "Beorning Wrath",
        [ fr ] = "",
        [ de ] = "Beorninger: Zorn",
        [ ru ] = ""
    },

    Options_Color_Font_Name = {
        [ en ] = "Name Font",
        [ fr ] = "",
        [ de ] = "Name: Schriftart",
        [ ru ] = ""
    },

    Options_Color_Font_Unique_Name = {
        [ en ] = "Unique Name Font",
        [ fr ] = "",
        [ de ] = "Schriftart für den eigenen Namen",
        [ ru ] = ""
    },

    Options_Color_Font_Morale = {
        [ en ] = "Morale Font",
        [ fr ] = "",
        [ de ] = "Schriftart für Moralwerte",
        [ ru ] = ""
    },

    Options_Color_Font_Name_Outline = {
        [ en ] = "Name Font Outline",
        [ fr ] = "",
        [ de ] = "Textumriss für Namen",
        [ ru ] = ""
    },

    Options_Color_Font_Unique_Name_Outline = {
        [ en ] = "Unique Name Font Outline",
        [ fr ] = "",
        [ de ] = "Textumriss für den eigenen Namen",
        [ ru ] = ""
    },

    Options_Color_Font_Special = {
        [ en ] = "Special Effect Font",
        [ fr ] = "",
        [ de ] = "Schriftart für Spezialeffekte",
        [ ru ] = ""
    },

    --Class

    Options_Class_Hunter = {
        [ en ] = "Hunter",
        [ fr ] = "",
        [ de ] = "Jäger",
        [ ru ] = ""
    },

    Options_Class_Warden = {
        [ en ] = "Warden",
        [ fr ] = "",
        [ de ] = "Hüter",
        [ ru ] = ""
    },

    Options_Class_Burglar = {
        [ en ] = "Burglar",
        [ fr ] = "",
        [ de ] = "Schurke",
        [ ru ] = ""
    },

    Options_Class_Captain = {
        [ en ] = "Captain",
        [ fr ] = "",
        [ de ] = "Hauptmann",
        [ ru ] = ""
    },

    Options_Class_Champion = {
        [ en ] = "Champion",
        [ fr ] = "",
        [ de ] = "Waffenmeister",
        [ ru ] = ""
    },

    Options_Class_Guardian = {
        [ en ] = "Guardian",
        [ fr ] = "",
        [ de ] = "Wächter",
        [ ru ] = ""
    },

    Options_Class_Minstrel = {
        [ en ] = "Minstrel",
        [ fr ] = "",
        [ de ] = "Barde",
        [ ru ] = ""
    },

    Options_Class_Beorning = {
        [ en ] = "Beorning",
        [ fr ] = "",
        [ de ] = "Beorninger",
        [ ru ] = ""
    },

    Options_Class_LoreMaster = {
        [ en ] = "Lore-master",
        [ fr ] = "",
        [ de ] = "Kundiger",
        [ ru ] = ""
    },

    Options_Class_RuneKeeper = {
        [ en ] = "Rune-keeper",
        [ fr ] = "",
        [ de ] = "Runenbewahrer",
        [ ru ] = ""
    },

    Options_Class_Weaver = {
        [ en ] = "Weaver",
        [ fr ] = "",
        [ de ] = "Spinne",
        [ ru ] = ""
    },

    Options_Class_Reaver = {
        [ en ] = "Reaver",
        [ fr ] = "",
        [ de ] = "Schnitter",
        [ ru ] = ""
    },

    Options_Class_Defiler = {
        [ en ] = "Defiler",
        [ fr ] = "",
        [ de ] = "Saboteur",
        [ ru ] = ""
    },

    Options_Class_Stalker = {
        [ en ] = "Stalker",
        [ fr ] = "",
        [ de ] = "Warg",
        [ ru ] = ""
    },

    Options_Class_WarLeader = {
        [ en ] = "Warleader",
        [ fr ] = "",
        [ de ] = "Kriegsanführer",
        [ ru ] = ""
    },

    Options_Class_BlackArrow = {
        [ en ] = "Blackarrow",
        [ fr ] = "",
        [ de ] = "Schwarzpfeil",
        [ ru ] = ""
    },

    --Font

    Options_Font_Type = {
        [ en ] = "Type",
        [ fr ] = "",
        [ de ] = "Art",
        [ ru ] = ""
    },

    Options_Font_Size = {
        [ en ] = "Size",
        [ fr ] = "",
        [ de ] = "Größe",
        [ ru ] = ""
    },

    Options_Font_Outline = {
        [ en ] = "Outline",
        [ fr ] = "",
        [ de ] = "Umriss",
        [ ru ] = ""
    },

    Options_Font_Name = {
        [ en ] = "Name Text",
        [ fr ] = "",
        [ de ] = "Text: Name",
        [ ru ] = ""
    },

    Options_Font_Morale = {
        [ en ] = "Morale Text",
        [ fr ] = "",
        [ de ] = "Text: Moral",
        [ ru ] = ""
    },

    Options_Font_Power = {
        [ en ] = "Power Text",
        [ fr ] = "",
        [ de ] = "Text: Kraft",
        [ ru ] = ""
    },

    Options_Font_Effect = {
        [ en ] = "Effect Duration Text",
        [ fr ] = "",
        [ de ] = "Text: Effektdauer",
        [ ru ] = ""
    },

    Options_Font_Special = {
        [ en ] = "Special Effect Duration Text",
        [ fr ] = "",
        [ de ] = "Text: Dauer von Spezialeffekten",
        [ ru ] = ""
    },

    --Misc

    Options_Misc_Classic_Power = {
        [ en ] = "Enable Classic Power Bar",
        [ fr ] = "",
        [ de ] = "Klassischen Kraftbalken anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Class_Icon = {
        [ en ] = "Enable Class Icon",
        [ fr ] = "",
        [ de ] = "Klassensymbol anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Leader_Icon = {
        [ en ] = "Enable Leader Icon",
        [ fr ] = "",
        [ de ] = "Anführersymbol anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Name_Text = {
        [ en ] = "Enable Name Text",
        [ fr ] = "",
        [ de ] = "Textnamen anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Power_Text = {
        [ en ] = "Enable Power Text",
        [ fr ] = "",
        [ de ] = "Kraftwert anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Morale_Text = {
        [ en ] = "Enable Morale Text",
        [ fr ] = "",
        [ de ] = "Moralwert anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Track_All = {
        [ en ] = "Track All Effects ( Self Only )",
        [ fr ] = "",
        [ de ] = "Alle Effekte verfolgen ( nur für den eigenen Charakter )",
        [ ru ] = ""
    },
    
    Options_Misc_Track_CC = {
        [ en ] = "Track CC Effects ( Self Only )",
        [ fr ] = "",
        [ de ] = "CC-Effekte verfolgen ( nur für den eigenen Charakter )",
        [ ru ] = ""
    },

    Options_Misc_Track_Debuff = {
        [ en ] = "Track Debuff Effects ( Self Only )",
        [ fr ] = "",
        [ de ] = "Debuff-Effekte verfolgen ( nur für den eigenen Charakter )",
        [ ru ] = ""
    },

    Options_Misc_Track_Curable = {
        [ en ] = "Track Curable Effects ( Self Only )",
        [ fr ] = "",
        [ de ] = "nehmbare Effekte verfolgen ( nur für den eigenen Charakter )",
        [ ru ] = ""
    },

    Options_Misc_Effect = {
        [ en ] = "Enable Effect",
        [ fr ] = "",
        [ de ] = "Effektanzeige aktivieren",
        [ ru ] = ""
    },

    Options_Misc_Effect_Duration = {
        [ en ] = "Enable Effect Duration Text",
        [ fr ] = "",
        [ de ] = "Effektdauer anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Special = {
        [ en ] = "Enable Special Effect",
        [ fr ] = "",
        [ de ] = "Spezialeffekte: Effektanzeige aktivieren",
        [ ru ] = ""
    },

    Options_Misc_Special_Duration = {
        [ en ] = "Enable Special Effect Duration Text",
        [ fr ] = "",
        [ de ] = "Spezialeffekte: Effektdauer anzeigen",
        [ ru ] = ""
    },

    Options_Misc_Unique_Name_Color = {
        [ en ] = "Enable Unique Player Name Color",
        [ fr ] = "",
        [ de ] = "Individuelle Farbe für den eigenen Namen aktivieren",
        [ ru ] = ""
    },

    Options_Misc_Unique_Morale_Color = {
        [ en ] = "Enable Unique Player Morale Color",
        [ fr ] = "",
        [ de ] = "Individuelle Farbe für den eigenen Moralwert aktivieren",
        [ ru ] = ""
    },

    Options_Misc_Class_Morale_Color = {
        [ en ] = "Enable Class Morale Color",
        [ fr ] = "",
        [ de ] = "Klassenspezifische Farbe für Moralwerte aktivieren",
        [ ru ] = ""
    },

    Options_Misc_Morale_Threshold = {
        [ en ] = "Morale Threshold",
        [ fr ] = "",
        [ de ] = "Moralschwelle",
        [ ru ] = ""
    },

    Options_Misc_Reset = {
        [ en ] = "Reset All Options",
        [ fr ] = "",
        [ de ] = "Alle Optionen zurücksetzen",
        [ ru ] = ""
    },

    Options_Misc_Reset_Confirmation = {
        [ en ] = "Are you sure you want to reset the entire plugin?",
        [ fr ] = "",
        [ de ] = "Bist du sicher, dass du das gesamte Plugin zurücksetzen willst?",
        [ ru ] = ""
    },

    Options_Misc_Reset_Confirmation_Yes = {
        [ en ] = "Yes",
        [ fr ] = "",
        [ de ] = "Ja",
        [ ru ] = ""
    },

    Options_Misc_Reset_Confirmation_No = {
        [ en ] = "No",
        [ fr ] = "",
        [ de ] = "Nein",
        [ ru ] = ""
    },

    Options_Misc_Reset_Description = {
        [ en ] = "WARNING! This will completely reset the entire plugin to all default values!",
        [ fr ] = "",
        [ de ] = "WARNUNG! Dieser Vorgang wird das gesamte Plugin auf seine Standardeinstellungen zurücksetzen!",
        [ ru ] = ""
    },

    Options_Misc_Load = {
        [ en ] = "Load Global Settings",
        [ fr ] = "",
        [ de ] = "Globale Einstellungen laden",
        [ ru ] = ""
    },

    Options_Misc_Load_Confirmation = {
        [ en ] = "Are you sure you want to overwrite your local settings with your global settings?",
        [ fr ] = "",
        [ de ] = "Bist du sicher, dass du deine lokalen Einstellungen mit deinen globalen Einstellungen überschreiben willst?",
        [ ru ] = ""
    },

    Options_Misc_Save = {
        [ en ] = "Save Global Settings",
        [ fr ] = "",
        [ de ] = "Globale Einstellungen speichern",
        [ ru ] = ""
    },

    Options_Misc_Save_Confirmation = {
        [ en ] = "Are you sure you want to overwrite your global settings with your local settings?",
        [ fr ] = "",
        [ de ] = "Bist du sicher, dass du deine globalen Enstellungen mit deinen lokalen Einstellungen überschreiben willst?",
        [ ru ] = ""
    },

    --Help

    Options_Help = {
        [ en ] = "General functionality:\n\n" ..
                 "- You can rearrange the players in the grid by holding shift and using your mouse to drag them\n  around.\n\n" ..
                 "- You can customize the party layout even if you're not in a group by going to the 'Layout' tab and\n  enabling 'Layout Preview'.\n\n" ..
                 "- You can manually change the position of the party layout while in 'layout preview mode' by holding\n  shift and dragging it with your mouse.\n\n" ..
                 "- You can manually change the position of the quickmenu by holding shift and dragging it with your\n  mouse.\n\n" ..
                 "- If you are tracking 'Do Not Fall This Day' either as a normal or special effect it will remain on the\n  target if it dies while it's active. This is to help you save the use of your revival skills for when they are\n  really needed.\n\n" ..
                 "\nEffect Manager:\n\n" ..
                 "- To add effects to your library simply turn on effect recording which can be done in either three ways:\n  /miniraid record, by pressing the quickmenu button or by pressing the record button in the effect\n  window.\n\n" ..
                 "- New effects that are recorded and that don't currently exist in your library, will also be added to\n  the 'Recent' tab so you can easily see if you found any new effects.\n\n" ..
                 "- You can easily find any effect stored in your library or in any of the other tabs, both by filtering them\n  and searching for a specific keyword.\n\n" ..
                 "- After you have added an effect to your Tracking or Alerts simply go to the respective tab and select\n  the effect for further customization.\n\n" ..
                 "- You can choose to track an effect both on yourself and other players independently, this is the same\n  with Alerts.\n\n" ..
                 "- The 'Alert System' has a default message which is simply '<effect> on <player>', but you can customize the\n  message both for effects that you get and that others get. To include the name of the player in the\n  message simply write <player> and it will be replaced with the appropriate name.\n\n" ..
                 "- The Blacklist tab is currently only used on the effects that you get yourself, if you have enabled\n  tracking of debuffs/curables or everything.\n\n" ..
                 "\nKnown Issues:\n\n" ..
                 "- Ready checks are not currently possible to implement due to the related functions being broken in\n  Lua.\n\n" ..
                 "- Beorning Wrath only works if you're the Beorning, other players Wrath are not accessible from Lua.\n\n" ..
                 "- All effects can be tracked on yourself without any issues but due to the related functions being\n  broken in Lua, tracking some effects on other people will not work properly.\n\n" ..
                 "    - Tracking static effects which have no duration is not recommended on other players.\n\n" ..
                 "    - Tracking curable effects on other players is not recommended as they can potentially be removed.\n\n" ..
                 "    - Tracking effects that can be removed before their duration expires is not recommended on other\n      players.\n\n" ..
                 "    - This issue does not affect the 'Alert System', feel free to add any effect you want to it.\n\n" ..
                 "- Due to the same bug with tracking effects on other players. Effects that stack such as the Minstrel\n  skill 'Soliloquy of Spirit' that can stack up to 3 times, will not work properly on other players unless\n  you manually set it to the correct stack amount.\n\n" ..
                 "\nChat Commands:\n\n" ..
                 "    /miniraid options    ( Opens the option menu )\n" ..
                 "    /miniraid effects    ( Opens the effect menu )\n" ..
                 "    /miniraid reload    ( Reloads the plugin manually )\n" ..
                 "    /miniraid help    ( Displays all the chat commands )\n" ..
                 "\n\nContact Info:\n\n" ..
                 "If you have any feedback or questions about the plugin feel free to contact me either on Discord at 'Narim#9557' or ingame on 'Nimaya' ( Evernight ).",
        [ fr ] = "",
        [ de ] = "Allgemeine Benutzungshinweise:\n\n" ..
                 "- Du kannst die Spieler im Raster frei anordnen, indem du Umschalt/Shift gedrückt hältst und sie mit der Maus ziehst.\n\n" ..
                 "- Du kannst das Gruppenlayout auch dann verändern, wenn du nicht in einer Gruupe bist. Geh einfach in den Tab\n  'Layout' und aktiviere 'Layout Vorschau'.\n\n" ..
                 "- Du kannst die Position des Gruppenlayouts manuell verschieben während du dich im Modus 'Layout ( Vorschau )'\n  befindest, indem du Shift/Umschalt gedrückt hältst und es mit der Maus ziehst.\n\n" ..
                 "- Du kannst die Position des Schnellmenüs manuell verschieben wenn du Shift/Umschalt gedrückt hältst und es mit\n  deiner Maus dahin ziehst wo du es haben willst.\n\n" ..
                 "- Wenn du 'Tod heute nicht unterliegen' entweder als normalen Effekt oder als Spezialeffekt verfolgst, wird es dir auf\n  dem Ziel auch nach dessen Tod angezeigt, solange es aktiv ist. So kannst du deine Rezzes für Ziele aufsparen, die sie\n  wirklich brauchen.\n\n" ..
                 "\nEffekt Manager:\n\n" ..
                 "- Um Effekte zu deiner Bibliothek hinzuzufügen schalte einfach die Effektaufnahme an. Dazu hast du drei Möglichkeiten:\n  Über den Befehl /miniraid aufzeichnen, über den Schnellmenü-Button oder indem du auf den 'Aufzeichnen' Button im\n  Effektfenster drückst.\n\n" ..
                 "- Neue Effekte, die aufgezeichnet werden und noch nicht in deiner Bibliothek existieren, werden im Tab 'Kürzlich'\n  aufgeführt, damit du schnell und einfach sehen kannst, ob du irgendwelche neuen Effekte gefunden hast.\n\n" ..
                 "- Du kannst jeden verzeichneten Effekt ganz einfach in deiner Bibliothek oder jedem anderen Tab finden. Du kannst\n  entweder die Liste filtern oder sie nach einem spezifischen Begriff durchsuchen.\n\n" ..
                 "- Nachdem du einen Effekt in deine Liste für Effektverfolgung oder Warnungen aufgenommen hast, kannst du im\n  entsprechenden Tab weitere individuelle Einstellungen dafür festlegen.\n\n" ..
                 "- Du kannst für alle Effekte unabhängig voneinander festlegen, ob du sie nur bei dir selbst oder/und bei anderen Spielern\n  verfolgen willst. Gleiches gilt für Warnungen.\n\n" ..
                 "- Der Standardtext im 'Warnsystem' ist '<Effekt> auf <Spieler>', aber du kannst die Nachricht individuell anpassen -\n  sowohl für Effekte, die auf dich angewendet werden, als auch für Effekte, die auf anderen Spielern auftreten. Um den\n  Namen des spezifischen Spielers in der Nachricht anzuzeigen, schreib einfach <Spieler>. Es wird dann immer durch den\n  richtigen Namen ersetzt.\n\n" ..
                 "- Der Tab für die Schwarze Liste funktioniert momentan nur für Effekte, die du selbst bekommst, wenn du die\n  Aufzeichnung von Debuffs/nehmbaren Effekten oder Allem aktiviert hast.\n\n" ..
                 "\nBekannte Probleme:\n\n" ..
                 "- Bereitschaftskontrollen können aktuell leider nicht implementiert werden, weil die entsprechenden Funktionen in\n  Lua defekt sind.\n\n" ..
                 "- Beorninger: Zornanzeige funktioniert nur, wenn du selbst der Beorninger bist. Informationen zum Zorn anderer\n  Beorninger sind in Lua derzeit nicht zugänglich.\n\n" ..
                 "- Auf dir selbst können alle Effekte einwandfrei verfolgt werden, aber aufgrund von Problemen mit defekten Funktionen\n  in Lua funktioniert das Verfolgen mancher Effekte auf anderen Spielern aktuell leider nicht lückenlos.\n\n" ..
                 "    - Das Verfolgen statischer Effekte ohne spezifizierte Dauer wird deshalb auf anderen Spielern nicht empfohlen.\n\n" ..
                 "    - Das Verfolgen nehmbarer Effekte auf anderen Spielern wird nicht empfohlen, da sie möglicherweise genommen sein\n      könnten.\n\n" ..
                 "    - Das Verfolgen von Effekten, die vor Ablauf ihrer Dauer genommen werden können, wird auf anderen Spielern nicht\n      empfohlen.\n\n" ..
                 "    - Diese Problematik betrifft nicht das 'Warnsystem'. Füge dort gern jeden Effekt hinzu, den du wilst.\n\n" ..
                 "- Aufgrund desselben Bugs, der das Verfolgen von Effekten auf anderen Spielern erschwert, fuktioniert das Verfolgen\n  von stapelbaren Effekten wie z.B. beim Barden 'Selbstgespräch des Geistes' auf anderen Spielern nur dann, wenn du\n  manuell die korrekte Menge an Stapeln dafür eingestellt hast.\n\n" ..
                 "\nChatbefehle:\n\n" ..
                 "    /miniraid optionen    ( Öffnet das Optionen-Menü )\n" ..
                 "    /miniraid effekte    ( Öffnet das Effekte-Menü )\n" ..
                 "    /miniraid neu laden    ( Lädt das Plugin manuell neu )\n" ..
                 "    /miniraid hilfe    ( Zeigt alle Chatbefehle an )\n" ..
                 "\n\nKontaktinformationen:\n\n" ..
                 "Solltest du Feedback oder irgendwelche Fragen zu diesem Plugin haben, dann kontaktiere mich gern entweder auf Discord unter 'Narim#9557' oder im Spiel unter 'Nimaya' ( Evernight ).",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Effects menu

    Effects = {
        [ en ] = "MiniRaid Effects",
        [ fr ] = "",
        [ de ] = "MiniRaid Effekte",
        [ ru ] = ""
    },

    Effects_Record = {
        [ en ] = "Record effects",
        [ fr ] = "",
        [ de ] = "Effekte aufzeichnen",
        [ ru ] = ""
    },

    Effects_Record_Active = {
        [ en ] = "Recording...",
        [ fr ] = "",
        [ de ] = "Aufzeichnung aktiv...",
        [ ru ] = ""
    },

    Effects_Record_Active_Stop = {
        [ en ] = "Stop Recording",
        [ fr ] = "",
        [ de ] = "Aufzeichnung stoppen",
        [ ru ] = ""
    },

    Effects_Record_Inactive = {
        [ en ] = "Stopped",
        [ fr ] = "",
        [ de ] = "gestoppt",
        [ ru ] = ""
    },

    Effects_Record_Inactive_Start = {
        [ en ] = "Start Recording",
        [ fr ] = "",
        [ de ] = "Aufzeichnung starten",
        [ ru ] = ""
    },

    Effects_Enable = {
        [ en ] = "Enable Effects",
        [ fr ] = "",
        [ de ] = "Effekte aktivieren",
        [ ru ] = ""
    },

    Effects_Enable_Alert = {
        [ en ] = "Enable Alerts",
        [ fr ] = "",
        [ de ] = "Warnungen aktivieren",
        [ ru ] = ""
    },

    Effects_Enable_Special = {
        [ en ] = "Enable Special Effect",
        [ fr ] = "",
        [ de ] = "Spezialeffekt aktivieren",
        [ ru ] = ""
    },

    Effects_Track_Debuff = {
        [ en ] = "Track debuffs on yourself",
        [ fr ] = "",
        [ de ] = "Selbst: Debuffs verfolgen",
        [ ru ] = ""
    },

    Effects_Track_Curable = {
        [ en ] = "Track curables on yourself",
        [ fr ] = "",
        [ de ] = "Selbst: Nehmbare Effekte verfolgen",
        [ ru ] = ""
    },

    Effects_Track_All = {
        [ en ] = "Track everything on yourself",
        [ fr ] = "",
        [ de ] = "Selbst: Alles verfolgen",
        [ ru ] = ""
    },

    --Tabs

    Effects_Tab_1 = {
        [ en ] = "Blacklist",
        [ fr ] = "",
        [ de ] = "Schwarze Liste",
        [ ru ] = ""
    },

    Effects_Tab_2 = {
        [ en ] = "Special",
        [ fr ] = "",
        [ de ] = "Spezial",
        [ ru ] = ""
    },

    Effects_Tab_3 = {
        [ en ] = "Alerts",
        [ fr ] = "",
        [ de ] = "Warnungen",
        [ ru ] = ""
    },

    Effects_Tab_4 = {
        [ en ] = "Tracking",
        [ fr ] = "",
        [ de ] = "Verfolgung",
        [ ru ] = ""
    },

    Effects_Tab_5 = {
        [ en ] = "Library",
        [ fr ] = "",
        [ de ] = "Archiv",
        [ ru ] = ""
    },

    Effects_Tab_6 = {
        [ en ] = "Recent",
        [ fr ] = "",
        [ de ] = "Kürzlich",
        [ ru ] = ""
    },
    
    ------------------------------------------------------

    --Info

    Effects_Info_Header = {
        [ en ] = "Selected Effect",
        [ fr ] = "",
        [ de ] = "Ausgewählter Effekt",
        [ ru ] = ""
    },

    Effects_Info_Header_Special = {
        [ en ] = "Special Effect",
        [ fr ] = "",
        [ de ] = "Spezialeffekt",
        [ ru ] = ""
    },

    Effects_Info_Debuff = {
        [ en ] = "Debuff: ",
        [ fr ] = "",
        [ de ] = "Debuff: ",
        [ ru ] = ""
    },

    Effects_Info_Curable = {
        [ en ] = "Curable: ",
        [ fr ] = "",
        [ de ] = "Nehmbar: ",
        [ ru ] = ""
    },

    Effects_Info_Duration = {
        [ en ] = "Duration: ",
        [ fr ] = "",
        [ de ] = "Dauer: ",
        [ ru ] = ""
    },

    Effects_Info_Category = {
        [ en ] = "Category: ",
        [ fr ] = "",
        [ de ] = "Kategorie: ",
        [ ru ] = ""
    },

    Effects_Info_Description = {
        [ en ] = "Description: ",
        [ fr ] = "",
        [ de ] = "Beschreibung: ",
        [ ru ] = ""
    },

    --List

    Effects_List_Filter = {
        [ en ] = "Filter:",
        [ fr ] = "",
        [ de ] = "Filter:",
        [ ru ] = ""
    },

    Effects_List_All = {
        [ en ] = "All",
        [ fr ] = "",
        [ de ] = "Alle",
        [ ru ] = ""
    },

    Effects_List_Debuffs = {
        [ en ] = "Debuffs",
        [ fr ] = "",
        [ de ] = "Debuffs",
        [ ru ] = ""
    },

    Effects_List_Curables = {
        [ en ] = "Curables",
        [ fr ] = "",
        [ de ] = "Nehmbare",
        [ ru ] = ""
    },

    Effects_List_Search = {
        [ en ] = "Search",
        [ fr ] = "",
        [ de ] = "Suchen",
        [ ru ] = ""
    },

    --Config

    Effects_Config_Header = {
        [ en ] = "Configuration",
        [ fr ] = "",
        [ de ] = "Einstellungen",
        [ ru ] = ""
    },

    Effects_Config_Track_Self = {
        [ en ] = "Track on yourself",
        [ fr ] = "",
        [ de ] = "Selbst: Verfolgen",
        [ ru ] = ""
    },

    Effects_Config_Track_Others = {
        [ en ] = "Track on others",
        [ fr ] = "",
        [ de ] = "Andere: Verfolgen",
        [ ru ] = ""
    },

    Effects_Config_Stack = {
        [ en ] = "Effect stack amount",
        [ fr ] = "",
        [ de ] = "Menge an Effektstapeln",
        [ ru ] = ""
    },

    Effects_Config_Note = {
        [ en ] = "Note: This slider is incase the effect can stack more than once on other players, it does nothing on yourself. An example would be the Minstrel skill 'Soliloquy of Spirit' which can stack up to three times per player.",
        [ fr ] = "",
        [ de ] = "Erklärung: Dieser Regler bezieht sich auf den Fall, dass ein Effekt mehrfach auf andere Spieler gestapelt werden kann. Er hat keine Auswirkungen auf dich selbst. Beispiel: 'Selbstgespräch des Geistes' vom Barden kann dreifach auf einen Spieler gestapelt werden.",
        [ ru ] = ""
    },

    --Alert Config

    Effects_Config_Alert_Header = {
        [ en ] = "Configuration",
        [ fr ] = "",
        [ de ] = "Einstellungen",
        [ ru ] = ""
    },

    Effects_Config_Alert_Enable_Self = {
        [ en ] = "Alert effect on yourself",
        [ fr ] = "",
        [ de ] = "Warnen, wenn der Effekt auf dir selbst aktiv wird",
        [ ru ] = ""
    },

    Effects_Config_Alert_Message_Self = {
        [ en ] = "Custom message for yourself",
        [ fr ] = "",
        [ de ] = "Individuelle Warnnachricht für dich selbst",
        [ ru ] = ""
    },

    Effects_Config_Alert_Enable_Others = {
        [ en ] = "Alert effect on others",
        [ fr ] = "",
        [ de ] = "Warnen, wenn der Effekt auf anderen Spielern aktiv wird",
        [ ru ] = ""
    },

    Effects_Config_Alert_Message_Others = {
        [ en ] = "Custom message for others",
        [ fr ] = "",
        [ de ] = "Individuelle Warnnachricht für andere Ziele",
        [ ru ] = ""
    },

    Effects_Config_Alert_Placeholder = {
        [ en ] = "Default",
        [ fr ] = "",
        [ de ] = "Standard",
        [ ru ] = ""
    },

    Effects_Config_Alert_Note = {
        [ en ] = "This allows you to override the alert message displayed on your screen with your own message. You can include <player> in the message, which will be replaced with the name of the player who got the effect." .. 
                 "\n\nExample: \"Watch out, <player> is bound!\"",
        [ fr ] = "",
        [ de ] = "Diese Einstelkung ermöglicht es dir, die Standardnachricht auf deinem Bildschirm durch einen individuellen Text zu ersetzen. Du kannst <spieler> in die Nachricht einbauen. Das wird dann durch den Namen des Spielers ersetzt, der den Effekt hat." .. 
                 "\n\nBeispiel: \"Achtung, <spieler> ist eingebunden!\"",
        [ ru ] = ""
    },

    ------------------------------------------------------

    --Button

    Effects_Button_Track = {
        [ en ] = "Add effect to tracking",
        [ fr ] = "",
        [ de ] = "Effekt zur Verfolgung hinzufügen",
        [ ru ] = ""
    },

    Effects_Button_Alert = {
        [ en ] = "Add effect to alerts",
        [ fr ] = "",
        [ de ] = "Effekt zu Warnungen hinzufügen",
        [ ru ] = ""
    },

    Effects_Button_Blacklist = {
        [ en ] = "Add effect to the blacklist",
        [ fr ] = "",
        [ de ] = "Effekt auf die Schwarze Liste setzen",
        [ ru ] = ""
    },

    Effects_Button_Special = {
        [ en ] = "Set effect as special effect",
        [ fr ] = "",
        [ de ] = "Effekt als Spezialeffekt festlegen",
        [ ru ] = ""
    },

    Effects_Button_Remove = {
        [ en ] = "Remove Effect",
        [ fr ] = "",
        [ de ] = "Effekt entfernen",
        [ ru ] = ""
    }
}